/*

  This file is part of EASYMOVE.DLL source code, see MAIN.C for
  detailed information.

  Copyright (C) 2000-2001 Pavel Vitis
  pavel.vitis@seznam.cz
  http://lsg.come.to/


  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

/****************************************************************************
****************************************************************************/

#include <windows.h>
#include "main.h"

// Test if window is application window
BOOL isAppWindow( HWND wnd )
{
	DWORD nStyle;
	HWND hOwner, hParent;
	BOOL bResult;

	bResult = TRUE;

	nStyle = GetWindowLong( wnd, GWL_STYLE );
	if ( ((nStyle & WS_CHILD) != 0) || ((nStyle & WS_VISIBLE) == 0) )
		bResult = FALSE;

	nStyle = GetWindowLong( wnd, GWL_EXSTYLE );
	if ( (nStyle & WS_EX_TOOLWINDOW) != 0 )
		bResult = FALSE;

	hOwner = GetWindow( wnd, GW_OWNER );
// CHANGE 1.1: This check disabled because we want to move dialog windows
//	if ( (hOwner != NULL) && bResult )
//		bResult = !isAppWindow( hOwner );

	hParent = GetParent( wnd );
// CHANGE 1.1: This check disabled because we want to move dialog windows
//	if ( hParent != NULL )
//		bResult = FALSE;

	nStyle = GetWindowLong( wnd, GWL_USERDATA );
	if ( nStyle == magicDWord )
		bResult = FALSE;

	return bResult;
}

// Test if window parameters match any record in windows-exclusion-list,
// if so, return TRUE
BOOL excluded_window(LPSTR module, LPSTR class, LPSTR title)
{
	// No exclusion-list defined
	if ((config.ex_win_list == NULL) || (config.ex_win_cnt == 0))
		return FALSE;

	for (int i = 0; i < config.ex_win_cnt; i++)
	{
		BOOL matched = FALSE;
		// Test for module (executable) path
		if ( (config.ex_win_list[i].module != NULL) && (strlen(config.ex_win_list[i].module) > 0) )
		{
			if ((module != NULL) && match(config.ex_win_list[i].module, module))
				matched = TRUE;
			else
				continue;
		}

		// Test for class name
		if ( (config.ex_win_list[i].class != NULL) && (strlen(config.ex_win_list[i].class) > 0) )
		{
			if ((class != NULL) && match(config.ex_win_list[i].class, class))
				matched = TRUE;
			else
				continue;
		}

		// Test for window title
		if ( (config.ex_win_list[i].title != NULL) && (strlen(config.ex_win_list[i].title) > 0) )
		{
			if ((title != NULL) && match(config.ex_win_list[i].title, title))
				matched = TRUE;
			else
				continue;
		}

		// Match
		if (matched)
		{
			LOG("Excluded window match:");
			LOGF("  module: '%s'", module);
			LOGF("  class : '%s'", class);
			LOGF("  title : '%s'", title);

			// Play StrokeExcludeSound
//			sound(NULL, config.def_exclude_snd);
			return TRUE;
		}
	}

	return FALSE;
}

