/*

  This file is part of EASYMOVE.DLL source code, see MAIN.C for
  detailed information.

  Copyright (C) 2000-2001 Pavel Vitis
  pavel.vitis@seznam.cz
  http://lsg.come.to/


  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

/****************************************************************************
****************************************************************************/

#ifndef __MAIN_H
#define __MAIN_H

//#include "wharfdata.h"
#include "lsapi.h"

#define LOGGING

#ifdef LOGGING
	char logmsg[256];
	LPVOID lpMsgBuf;

	#define LOG(TXT)		{ OutputDebugString(ST_NAME TEXT(": ") TXT "\n"); }
	#define LOGF(TXT,PRM)	{ sprintf(logmsg, ST_NAME TEXT(": ") TXT "\n", PRM); \
							OutputDebugString(logmsg); }
	#define LOGIF(IF,TXT)	{ if (IF) OutputDebugString(ST_NAME TEXT(": ") TXT "\n"); }
	#define LOGLE			{ FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, NULL, GetLastError(), \
							MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), (LPTSTR) &lpMsgBuf, 0, NULL); \
							OutputDebugString(lpMsgBuf); \
							LocalFree( lpMsgBuf ); }
#else
	#define LOG(TXT)		{}
	#define LOGF(TXT,PRM)	{}
	#define LOGIF(IF,TXT)	{}
	#define LOGLE			{}
#endif

#define true TRUE
#define false FALSE;
typedef BOOL bool;

#define STRVALID(s) ((s != NULL) && (strlen(s) > 0))
#define NELEMENTS(a) (sizeof(a)/sizeof(a[0]))

#define	NEED_HOOKDLL_VER	0x0202

// strings
#define ST_SHORTNAME      TEXT("easymove")
#define ST_NAME           TEXT("EASYMOVE.DLL")
#define ST_VERSION        TEXT("1.3")
#define ST_AUTHOR         TEXT("pavelvitis")
#define ST_REVID          ST_SHORTNAME TEXT(" ") ST_VERSION TEXT(" (") __DATE__ TEXT(" / ") __TIME__ TEXT(") ") ST_AUTHOR

// window classes
#define WC_LSDESKTOP      TEXT("DesktopBackgroundClass")
#define WC_MAIN           TEXT("LS_") ST_SHORTNAME

//#define TOKEN		TEXT("*easymove")

#define ALTKEY ((GetAsyncKeyState(VK_MENU) & 0x8000U) != 0)
#define CTRLKEY ((GetAsyncKeyState(VK_CONTROL) & 0x8000U) != 0)
#define LSHIFTKEY ((GetAsyncKeyState(VK_LSHIFT) & 0x8000U) != 0)
#define RSHIFTKEY ((GetAsyncKeyState(VK_RSHIFT) & 0x8000U) != 0)
#define SHIFTKEY ((GetAsyncKeyState(VK_SHIFT) & 0x8000U) != 0)

#define HK_SHIFT	0x0001U
#define HK_ALT		0x0002U
#define HK_CTRL		0x0004U

#define LMBUTTON ((GetAsyncKeyState(VK_LBUTTON) & 0x8000U) != 0)
#define RMBUTTON ((GetAsyncKeyState(VK_RBUTTON) & 0x8000U) != 0)
#define MMBUTTON ((GetAsyncKeyState(VK_MBUTTON) & 0x8000U) != 0)

typedef struct EX_WIN
{
	LPSTR module;
	LPSTR class;
	LPSTR title;
} EX_WIN;

typedef struct CONFIG
{
	BOOL enabled;
	UINT ex_win_cnt;
	EX_WIN *ex_win_list;
	char *def_snd;
	UINT mbutton;
	UINT hotkey;
} CONFIG;

extern CONFIG config;

extern HINSTANCE DLLInstance;

extern HWND ToolWindow;
extern HWND hLitestep;
extern HWND hDesktop;
extern char *steprcPath;

extern ATOM LWinKey;
extern ATOM RWinKey;

BOOL createToolWindow( void );
void destroyToolWindow( void );

BOOL isAppWindow( HWND );
void loadExcludedWindows();

BOOL loadConfig(void);
BOOL reloadConfig(void);
void freeConfig(void);
void hook_init(void);

BOOL excluded_window(LPSTR, LPSTR, LPSTR);
//BOOL onExcludedWindow(LPSTR module, LPSTR class, LPSTR title, PSTROKE stroke);
//BOOL onRequiredWindow(LPSTR module, LPSTR class, LPSTR title, PSTROKE stroke);

void sound( LPCTSTR, LPCTSTR );

/*
#ifdef __cplusplus
extern "C" {
#endif

__declspec( dllexport ) int initModule( HWND, HINSTANCE, wharfDataType* );
__declspec( dllexport ) int initModuleEx( HWND, HINSTANCE, LPCSTR );
__declspec( dllexport ) void quitModule( HINSTANCE );
__declspec( dllexport ) BOOL WINAPI LibMain( HINSTANCE, DWORD, LPVOID );

#ifdef __cplusplus
}
#endif
*/

#endif	//__MAIN_H
