#ifndef __HOOKDLL_
#define __HOOKDLL_

#include <windows.h>

#define HOOK_DLL "KMHOOK.DLL"

// Hook events that can be passed into SetMouseHook, SetKeyboardHook and
// SetShellHook functions. They specify, which of system messages will
// be send to HWND
// These are bit masks

#define EV_MOUSEMOVE		0x00000001
#define EV_LBUTTONDOWN		0x00000002
#define EV_RBUTTONDOWN		0x00000004
#define EV_MBUTTONDOWN		0x00000008
#define EV_LBUTTONUP		0x00000010
#define EV_RBUTTONUP		0x00000020
#define EV_MBUTTONUP		0x00000040
#define EV_LBUTTONDBLCLK	0x00000080
#define EV_RBUTTONDBLCLK	0x00000100
#define EV_MBUTTONDBLCLK	0x00000200
#define EV_MOUSEWHEEL		0x00000400
#define EV_NCMOUSEMOVE		0x00000800
#define EV_NCHITTEST 		0x00001000
#define EV_NCLBUTTONDOWN	0x00002000
#define EV_NCRBUTTONDOWN	0x00004000
#define EV_NCMBUTTONDOWN	0x00008000
#define EV_NCLBUTTONUP		0x00010000
#define EV_NCRBUTTONUP		0x00020000
#define EV_NCMBUTTONUP		0x00040000
#define EV_NCLBUTTONDBLCLK	0x00080000
#define EV_NCRBUTTONDBLCLK	0x00100000
#define EV_NCMBUTTONDBLCLK	0x00200000

#define EV_KEYDOWN			0x00400800
#define EV_KEYUP			0x00800000

#define EV_WCREATED			0x01000000
#define EV_WDESTROYED		0x02000000
#define EV_WACTIVATED		0x04000000
#define EV_SHREDRAW			0x08000000
#define EV_SHTASKMAN		0x10000000
#define EV_SHACTIVATE		0x20000000
#define EV_SHLANGUAGE		0x40000000

// New in version
#define EV_XBUTTONS			0x80000000
#define EV_XBUTTONDOWN		EV_XBUTTONS
#define EV_NCXBUTTONDOWN	EV_XBUTTONS
#define EV_XBUTTONUP		EV_XBUTTONS
#define EV_NCXBUTTONUP		EV_XBUTTONS
#define EV_XBUTTONDBLCLK	EV_XBUTTONS
#define EV_NCXBUTTONDBLCLK	EV_XBUTTONS
// -----------

#define EV_MOUSEDOWNS		EV_LBUTTONDOWN | EV_RBUTTONDOWN | EV_MBUTTONDOWN | EV_XBUTTONDOWN
#define EV_MOUSEUPS			EV_LBUTTONUP | EV_RBUTTONUP | EV_MBUTTONUP | EV_XBUTTONUP
#define EV_MOUSEDBLCLKS		EV_LBUTTONDBLCLK | EV_RBUTTONDBLCLK | EV_MBUTTONDBLCLK | EV_XBUTTONDBLCLK

#define EV_MOUSEBUTTONS		EV_MOUSEDOWNS | EV_MOUSEUPS | EV_MOUSEDBLCLKS

#define EV_NCMOUSEDOWNS		EV_NCLBUTTONDOWN | EV_NCRBUTTONDOWN | EV_NCMBUTTONDOWN | EV_NCXBUTTONDOWN
#define EV_NCMOUSEUPS		EV_NCLBUTTONUP | EV_NCRBUTTONUP | EV_NCMBUTTONUP | EV_NCXBUTTONUP
#define EV_NCMOUSEDBLCLKS	EV_NCLBUTTONDBLCLK | EV_NCRBUTTONDBLCLK | EV_NCMBUTTONDBLCLK | EV_NCXBUTTONDBLCLK

#define EV_NCMOUSEBUTTONS	EV_NCMOUSEDOWNS | EV_NCMOUSEUPS | EV_NCMOUSEDBLCLKS

#define EV_MOUSE			EV_MOUSEMOVE | EV_NCMOUSEMOVE | EV_MOUSEBUTTONS | EV_NCMOUSEBUTTONS

#define EV_KEYBOARD			EV_KEYDOWN | EV_KEYUP

#define EV_SHELL			EV_WCREATED	| EV_WDESTROYED	| EV_WACTIVATED	| EV_SHREDRAW | \
							EV_SHTASKMAN | EV_SHACTIVATE | EV_SHLANGUAGE

#define EV_ALL				0xFFFFFFFF

//#ifndef WM_XBUTTONDOWN
	#define WM_XBUTTONDOWN                  0x020B
	#define WM_XBUTTONUP                    0x020C
	#define WM_XBUTTONDBLCLK                0x020D

//	#define WM_NCXBUTTONDOWN	0x020B
//	#define WM_NCXBUTTONUP		0x020C
//	#define WM_NCXBUTTONDBLCLK	0x020D

	#define GET_KEYSTATE_WPARAM(wParam)     (LOWORD(wParam))
	#define GET_NCHITTEST_WPARAM(wParam)    ((short)LOWORD(wParam))
	#define GET_XBUTTON_WPARAM(wParam)      (HIWORD(wParam))

	/* XButton values are WORD flags */
	#define XBUTTON1      0x0001
	#define XBUTTON2      0x0002

	#define MK_XBUTTON1   0x0020
	#define MK_XBUTTON2   0x0040
//#endif

/******************************************************************************************/

#define MAX_HOOK_WND 100

typedef DWORD EVENTS;

typedef struct {
	HWND HookWnd;
	void *SharedMem;
	BOOL setCapture;
	EVENTS events;
} HOOKREC;

typedef struct {
	MOUSEHOOKSTRUCT MHStruct;
	HHOOK hShellHook;
	HHOOK hMouseHook;
	HHOOK hKeyboardHook;
	UINT WM_MONITORKEYBOARD;
	UINT WM_MONITORMOUSE;
	UINT WM_MONITORSHELL;
	UINT uMSH_MOUSEWHEEL;
	HINSTANCE DLLInstance;
	UINT hookwndcnt;
	UINT mhookcnt;
	UINT khookcnt;
	UINT shookcnt;
	UINT usagecnt;
	HWND toolwnd;
	HOOKREC hookrec[MAX_HOOK_WND];
} SHDATASTRUCT, *PSHDATASTRUCT;

#ifndef __MAKE_DLL_

	extern UINT MouseMsg;
	extern UINT KeyboardMsg;
	extern UINT ShellMsg;
	extern PSHDATASTRUCT SharedMem;

	BOOL loadHookDLL( HINSTANCE, WORD );
	void unloadHookDLL( void );

	typedef UINT (*GETMSGPROC) ( void );

	typedef BOOL (*SETHOOKPROC)( HWND, EVENTS );
	extern SETHOOKPROC setMouseHook, setKeyboardHook, setShellHook;

	typedef BOOL (*UNSETHOOKPROC)( HWND );
	extern UNSETHOOKPROC unsetMouseHook, unsetKeyboardHook, unsetShellHook;

	typedef BOOL (*BOOLPROC)( void );

	typedef WORD (*WORDPROC)( void );
	typedef PSHDATASTRUCT (*GETSHAREDMEM)( void );

	typedef BOOL (*SENDMOUSECLICKPROC)( HWND, UINT, POINT );
	extern SENDMOUSECLICKPROC sendMouseClick;

	typedef BOOL (*SENDKEYSPROC)( UINT FAR *, UINT );
	extern SENDKEYSPROC sendKeys;

#endif // __MAKE_DLL_

#endif // __HOOKDLL_
