/*

  This file is part of KMHOOK.DLL source code
  KMHOOK.DLL is native Win32 library providing system-wide hooks

  Copyright (C) 2000-2001 Pavel Vitis
  pavel.vitis@seznam.cz
  http://lsg.come.to/

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef __HOOKEVNT_
#define __HOOKEVNT_

// Hook events that can be passed into SetMouseHook, SetKeyboardHook and
// SetShellHook functions. They specify, which of system messages will
// be send to HWND
// These are bit masks

#define EV_MOUSEMOVE		0x00000001
#define EV_LBUTTONDOWN		0x00000002
#define EV_RBUTTONDOWN		0x00000004
#define EV_MBUTTONDOWN		0x00000008
#define EV_LBUTTONUP		0x00000010
#define EV_RBUTTONUP		0x00000020
#define EV_MBUTTONUP		0x00000040
#define EV_LBUTTONDBLCLK	0x00000080
#define EV_RBUTTONDBLCLK	0x00000100
#define EV_MBUTTONDBLCLK	0x00000200
#define EV_MOUSEWHEEL		0x00000400
#define EV_NCMOUSEMOVE		0x00000800
#define EV_NCHITTEST 		0x00001000
#define EV_NCLBUTTONDOWN	0x00002000
#define EV_NCRBUTTONDOWN	0x00004000
#define EV_NCMBUTTONDOWN	0x00008000
#define EV_NCLBUTTONUP		0x00010000
#define EV_NCRBUTTONUP		0x00020000
#define EV_NCMBUTTONUP		0x00040000
#define EV_NCLBUTTONDBLCLK	0x00080000
#define EV_NCRBUTTONDBLCLK	0x00100000
#define EV_NCMBUTTONDBLCLK	0x00200000

#define EV_KEYDOWN			0x00400800
#define EV_KEYUP			0x00800000

#define EV_WCREATED			0x01000000
#define EV_WDESTROYED		0x02000000
#define EV_WACTIVATED		0x04000000
#define EV_SHREDRAW			0x08000000
#define EV_SHTASKMAN		0x10000000
#define EV_SHACTIVATE		0x20000000
#define EV_SHLANGUAGE		0x40000000


#define EV_MOUSEDOWNS		EV_LBUTTONDOWN | EV_RBUTTONDOWN | EV_MBUTTONDOWN
#define EV_MOUSEUPS			EV_LBUTTONUP | EV_RBUTTONUP | EV_MBUTTONUP
#define EV_MOUSEDBLCLKS		EV_LBUTTONDBLCLK | EV_RBUTTONDBLCLK | EV_MBUTTONDBLCLK

#define EV_MOUSEBUTTONS		EV_MOUSEDOWNS | EV_MOUSEUPS | EV_MOUSEDBLCLKS

#define EV_NCMOUSEDOWNS		EV_NCLBUTTONDOWN | EV_NCRBUTTONDOWN | EV_NCMBUTTONDOWN
#define EV_NCMOUSEUPS		EV_NCLBUTTONUP | EV_NCRBUTTONUP | EV_NCMBUTTONUP
#define EV_NCMOUSEDBLCLKS	EV_NCLBUTTONDBLCLK | EV_NCRBUTTONDBLCLK | EV_NCMBUTTONDBLCLK

#define EV_NCMOUSEBUTTONS	EV_NCMOUSEDOWNS | EV_NCMOUSEUPS | EV_NCMOUSEDBLCLKS

#define EV_MOUSE			EV_MOUSEMOVE | EV_NCMOUSEMOVE | EV_MOUSEBUTTONS | EV_NCMOUSEBUTTONS

#define EV_KEYBOARD			EV_KEYDOWN | EV_KEYUP

#define EV_SHELL			EV_WCREATED	| EV_WDESTROYED	| EV_WACTIVATED	| EV_SHREDRAW | \
							EV_SHTASKMAN | EV_SHACTIVATE | EV_SHLANGUAGE

#define EV_ALL				0xFFFFFFFF

#endif // __HOOKEVNT_
